==> italc_1.0.2.orig.tar.gz: italc-1.0.2/ica/resources/it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="it_IT">
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/ica_main.cpp" line="293"/>
        <source>iTALC Client on %1:%2</source>
        <translation>iTALC Client su %1:%2</translation>
    </message>
    <message>
        <location filename="../../common/src/system_service.cpp" line="261"/>
        <source>Unable to register service &apos;%1&apos;.</source>
        <translation>Non è possibile registrare il servizio &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../../common/src/system_service.cpp" line="289"/>
        <source>The Service Control Manager could not be contacted (do you have the neccessary rights?!) - the service &apos;%1&apos; was not registered.</source>
        <translation>Il gestore dei servizi (Service Control Manger) non può essere contattato (hai i diritti sufficienti?!) - il servizio &apos;%1&apos; non è stato registrato.</translation>
    </message>
    <message>
        <location filename="../../common/src/system_service.cpp" line="320"/>
        <source>The service &apos;%1&apos; is already registered.</source>
        <translation>Il servizio &apos;%1&apos; è già registrato.</translation>
    </message>
    <message>
        <location filename="../../common/src/system_service.cpp" line="328"/>
        <source>The service &apos;%1&apos; could not be registered.</source>
        <translation>Il servizio &apos;%1&apos; non può essere registrato.</translation>
    </message>
    <message>
        <location filename="../../common/src/system_service.cpp" line="599"/>
        <source>The service &apos;%1&apos; could not be stopped.</source>
        <translation>Il servizio &apos;%1&apos; non può essere fermato.</translation>
    </message>
    <message>
        <location filename="../../common/src/system_service.cpp" line="424"/>
        <source>The service &apos;%1&apos; has been unregistered.</source>
        <translation>Il servizio &apos;%1&apos; è stato rimosso.</translation>
    </message>
    <message>
        <location filename="../../common/src/system_service.cpp" line="436"/>
        <source>The service &apos;%1&apos; isn&apos;t registered and therefore can&apos;t be unregistered.</source>
        <translation>Il servizio &apos;%1&apos; non è registrato pertanto non può essere rimosso.</translation>
    </message>
    <message>
        <location filename="../../common/src/system_service.cpp" line="445"/>
        <source>The service &apos;%1&apos; could not be unregistered.</source>
        <translation>Il servizio &apos;%1&apos; non può essere rimosso.</translation>
    </message>
    <message>
        <location filename="../../common/src/system_service.cpp" line="613"/>
        <source>The service &apos;%1&apos; could not be found.</source>
        <translation>Il servizio &apos;%1&apos; non è stato trovato.</translation>
    </message>
    <message>
        <location filename="../../common/src/system_service.cpp" line="472"/>
        <source>The Service Control Manager could not be contacted (do you have the neccessary rights?!) - the service &apos;%1&apos; was not unregistered.</source>
        <translation>Il gestore dei servizi (Service Control Manger) non può essere contattato (hai i diritti sufficienti?!) - il servizio &apos;%1&apos; non è stato rimosso.</translation>
    </message>
    <message>
        <location filename="../../common/src/system_service.cpp" line="629"/>
        <source>The Service Control Manager could not be contacted (do you have the neccessary rights?!) - the service &apos;%1&apos; was not stopped.</source>
        <translation>Il gestore dei servizi (Service Control Manger) non può essere contattato (hai i diritti sufficienti?!) - il servizio &apos;%1&apos; non è stato fermato.</translation>
    </message>
    <message>
        <location filename="../../common/src/system_service.cpp" line="361"/>
        <source>The service &apos;%1&apos; was successfully registered.</source>
        <translation>Il servizio &apos;%1&apos; è stato registrato correttamente.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../common/src/local_system.cpp" line="53"/>
        <source>UPL (note for translators: the first three characters of this string are the accellerators (underlined characters) of the three input-fields in logon-dialog of windows - please keep this note as otherwise there are strange errors concerning logon-feature)</source>
        <translation>NPC (note for translators: the first three characters of this string are the accellerators (underlined characters) of the three input-fields in logon-dialog of windows - please keep this note as otherwise there are strange errors concerning logon-feature)</translation>
    </message>
    <message>
        <location filename="../../common/src/local_system.cpp" line="870"/>
        <source>iTALC-snapshots</source>
        <translation>iTALC-foto</translation>
    </message>
</context>
<context>
    <name>demoClient</name>
    <message>
        <location filename="../src/demo_client.cpp" line="42"/>
        <source>iTALC Demo</source>
        <translation>iTALC Presentazione</translation>
    </message>
</context>
<context>
    <name>isdServer</name>
    <message>
        <location filename="../src/isd_server.cpp" line="551"/>
        <source>Confirm access</source>
        <translation>Conferma l&apos;accesso</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="554"/>
        <source>Somebody at host %1 tries to access your screen. Do you want to grant him/her access?</source>
        <translation>Qualcuno dalla macchina %1 cerca di accedere al tuo video. Consenti l&apos;accesso?</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="572"/>
        <source>Never for this session</source>
        <translation>Mai per questa sessione</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="567"/>
        <source>Always for this session</source>
        <translation>Sempre per questa sessione</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="784"/>
        <source>Message from teacher</source>
        <translation>Messaggio dall&apos;insegnante</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="70"/>
        <source>ISD-server error</source>
        <translation>Server ISD: errore</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="75"/>
        <source>The ISD-server could not be started because port %1 is already in use. Please make sure that no other application is using this port and try again.</source>
        <translation>Il server ISD non può essere avviato perché la porta %1 è già in uso. Assicurarsi che non ci siano altre applicazioni che usano questa porta e riprovare.</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="850"/>
        <source>Authentication error</source>
        <translation>Errore di autenticazione</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="853"/>
        <source>Somebody (IP: %1) tried to access this computer but could not authenticate itself successfully!</source>
        <translation>Qualcuno (IP: %1) cerca di accedere a questo computer ma non riesce ad autenticarsi!</translation>
    </message>
</context>
<context>
    <name>messageBox</name>
    <message>
        <location filename="../../common/src/messagebox.cpp" line="75"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>remoteControlWidget</name>
    <message>
        <location filename="../src/remote_control_widget.cpp" line="371"/>
        <source>iTALC remote control (host %1)</source>
        <translation>iTALC controllo remoto (PC %1)</translation>
    </message>
</context>
<context>
    <name>remoteControlWidgetToolBar</name>
    <message>
        <location filename="../src/remote_control_widget.cpp" line="56"/>
        <source>Quit</source>
        <translation>Chiudi</translation>
    </message>
</context>
<context>
    <name>vncView</name>
    <message>
        <location filename="../src/vncview.cpp" line="54"/>
        <source>Establishing connection to %1 ...</source>
        <translation>Connessione con %1 ...</translation>
    </message>
</context>
</TS>

==> italc_1.0.7.orig.tar.gz: italc-1.0.7/ica/resources/it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="it_IT">
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/ica_main.cpp" line="300"/>
        <source>iTALC Client on %1:%2</source>
        <translation type="obsolete">iTALC Client su %1:%2</translation>
    </message>
    <message>
        <location filename="../src/system_service.cpp" line="265"/>
        <source>Unable to register service &apos;%1&apos;.</source>
        <translation>Non è possibile registrare il servizio &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../src/system_service.cpp" line="293"/>
        <source>The Service Control Manager could not be contacted (do you have the neccessary rights?!) - the service &apos;%1&apos; was not registered.</source>
        <translation>Il gestore dei servizi (Service Control Manger) non può essere contattato (hai i diritti sufficienti?!) - il servizio &apos;%1&apos; non è stato registrato.</translation>
    </message>
    <message>
        <location filename="../src/system_service.cpp" line="324"/>
        <source>The service &apos;%1&apos; is already registered.</source>
        <translation>Il servizio &apos;%1&apos; è già registrato.</translation>
    </message>
    <message>
        <location filename="../src/system_service.cpp" line="332"/>
        <source>The service &apos;%1&apos; could not be registered.</source>
        <translation>Il servizio &apos;%1&apos; non può essere registrato.</translation>
    </message>
    <message>
        <location filename="../src/system_service.cpp" line="367"/>
        <source>The service &apos;%1&apos; was successfully registered.</source>
        <translation>Il servizio &apos;%1&apos; è stato registrato correttamente.</translation>
    </message>
    <message>
        <location filename="../src/system_service.cpp" line="614"/>
        <source>The service &apos;%1&apos; could not be stopped.</source>
        <translation>Il servizio &apos;%1&apos; non può essere fermato.</translation>
    </message>
    <message>
        <location filename="../src/system_service.cpp" line="434"/>
        <source>The service &apos;%1&apos; has been unregistered.</source>
        <translation>Il servizio &apos;%1&apos; è stato rimosso.</translation>
    </message>
    <message>
        <location filename="../src/system_service.cpp" line="450"/>
        <source>The service &apos;%1&apos; isn&apos;t registered and therefore can&apos;t be unregistered.</source>
        <translation>Il servizio &apos;%1&apos; non è registrato, pertanto non può essere rimosso.</translation>
    </message>
    <message>
        <location filename="../src/system_service.cpp" line="460"/>
        <source>The service &apos;%1&apos; could not be unregistered.</source>
        <translation>Il servizio &apos;%1&apos; non può essere rimosso.</translation>
    </message>
    <message>
        <location filename="../src/system_service.cpp" line="628"/>
        <source>The service &apos;%1&apos; could not be found.</source>
        <translation>Il servizio &apos;%1&apos; non è stato trovato.</translation>
    </message>
    <message>
        <location filename="../src/system_service.cpp" line="487"/>
        <source>The Service Control Manager could not be contacted (do you have the neccessary rights?!) - the service &apos;%1&apos; was not unregistered.</source>
        <translation>Il gestore dei servizi (Service Control Manger) non può essere contattato (hai i diritti sufficienti?!) - il servizio &apos;%1&apos; non è stato rimosso.</translation>
    </message>
    <message>
        <location filename="../src/system_service.cpp" line="644"/>
        <source>The Service Control Manager could not be contacted (do you have the neccessary rights?!) - the service &apos;%1&apos; was not stopped.</source>
        <translation>Il gestore dei servizi (Service Control Manger) non può essere contattato (hai i diritti sufficienti?!) - il servizio &apos;%1&apos; non è stato fermato.</translation>
    </message>
    <message>
        <location filename="../src/ica_main.cpp" line="296"/>
        <source>iTALC Client %1 on %2:%3</source>
        <translation>iTALC Client su %1:%2:%3</translation>
    </message>
</context>
<context>
    <name>demoClient</name>
    <message>
        <location filename="../src/demo_client.cpp" line="44"/>
        <source>iTALC Demo</source>
        <translation>iTALC Presentazione</translation>
    </message>
</context>
<context>
    <name>isdServer</name>
    <message>
        <location filename="../src/isd_server.cpp" line="553"/>
        <source>Confirm access</source>
        <translation>Conferma l&apos;accesso</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="556"/>
        <source>Somebody at host %1 tries to access your screen. Do you want to grant him/her access?</source>
        <translation>Qualcuno dalla macchina %1 cerca di accedere al tuo video. Consenti l&apos;accesso?</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="559"/>
        <source>Never for this session</source>
        <translation>Mai per questa sessione</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="561"/>
        <source>Always for this session</source>
        <translation>Sempre per questa sessione</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="754"/>
        <source>Message from teacher</source>
        <translation>Messaggio dall&apos;insegnante</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="68"/>
        <source>ISD-server error</source>
        <translation>Server ISD: errore</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="73"/>
        <source>The ISD-server could not be started because port %1 is already in use. Please make sure that no other application is using this port and try again.</source>
        <translation>Il server ISD non può essere avviato perché la porta %1 è già in uso. Assicurarsi che non ci siano altre applicazioni che usano questa porta e riprovare.</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="806"/>
        <source>Authentication error</source>
        <translation>Errore di autenticazione</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="809"/>
        <source>Somebody (IP: %1) tried to access this computer but could not authenticate itself successfully!</source>
        <translation>Qualcuno (IP: %1) cerca di accedere a questo computer ma non riesce ad autenticarsi!</translation>
    </message>
</context>
</TS>
